@@ -277,8 +277,10 @@ void create_context_menu (GdkEventButton *event)
 
                         if (STREQ (ks.txt_fields[TYPE_TXT], "option block") && number_of_chldn_of_gp < NUMBER_OF_EXECUTE_OPTS) {
 							// Translation note: Do not translate "Startupnotify"
-                            gchar *headline_txt = ngettext (" Startupnotify Option", " Startupnotify Options", 
-                                                            (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_STARTUPNOTIFY_OPTS - 1));
+                            gchar *headline_txt = (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_STARTUPNOTIFY_OPTS - 1) ? _(" Startupnotify Option") : 
+                                                                                                                                                // Translation note: Do not translate "Startupnotify"
+                                                                                                                                                // 2-4 options are possible.
+                                                                                                                                                _(" Startupnotify Options"); 
 
                             create_cm_headline (context_menu, headline_txt);
                         }
@@ -314,8 +316,10 @@ void create_context_menu (GdkEventButton *event)
                             (STREQ (ks.txt_fields[TYPE_TXT], "option block") && 
                             gtk_tree_model_iter_n_children (ks.ts_model, &ks.iter) < NUMBER_OF_STARTUPNOTIFY_OPTS)) {
 							// Translation note: Do not translate "Execute"
-                            gchar *headline_txt = ngettext (" Execute Option", " Execute Options", 
-                                                            (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_EXECUTE_OPTS - 1));
+                            gchar *headline_txt = (gtk_tree_model_iter_n_children (ks.ts_model, &parent) == NUMBER_OF_EXECUTE_OPTS - 1) ? _(" Execute Option") : 
+                                                                                                                                          // Translation note: Do not translate "Execute"
+                                                                                                                                          // 2-5 options are possible.
+                                                                                                                                          _(" Execute Options");
 
                             create_cm_headline (context_menu, headline_txt);
                         }
@@ -506,15 +510,14 @@ void create_context_menu (GdkEventButton *event)
                      (!node_statuses.at_least_one_selected_node_is_expanded || 
                      expansion_statuses_of_subnodes.at_least_one_imd_ch_is_expanded)) || 
                     (exp_status_changes_cnt == CM_COLLAPSE && node_statuses.at_least_one_selected_node_is_expanded)) {
-                    g_autofree gchar *menu_item_txt = g_strdup_printf ((exp_status_changes_cnt == CM_RECURSIVELY) ? 
-                                                                       ngettext ("Expand Row Recursively", "Expand Rows Recursively", 
-                                                                                 (number_of_selected_rows == 1)) : 
-                                                                       ((exp_status_changes_cnt == CM_IMMEDIATE) ? 
-																	    // Translation note: "Imd. Ch. Only" means "immediate children only"
-                                                                        ngettext ("Expand Row (Imd. Ch. Only)", 
-																		          "Expand Rows (Imd. Ch. Only)", 
-                                                                                  (number_of_selected_rows == 1)) :
-                                                                        ngettext ("Collapse Row", "Collapse Rows", (number_of_selected_rows == 1))));
+                    g_autofree gchar *menu_item_txt = g_strdup_printf (
+                                                                       (exp_status_changes_cnt == CM_RECURSIVELY) ? ( (number_of_selected_rows == 1) ? _("Expand Row Recursively") : _("Expand Rows Recursively") ) : 
+                                                                       (
+                                                                        (exp_status_changes_cnt == CM_IMMEDIATE) ? ( (number_of_selected_rows == 1) ? _("Expand Row (Imd. Ch. Only)") : _("Expand Rows (Imd. Ch. Only)") ) : 
+																	   // Translation note: "Imd. Ch. Only" means "immediate children only""
+                                                                                                                    (number_of_selected_rows == 1) ? _("Collapse Row") : _("Collapse Rows")
+                                                                       )
+                                                                      );
                     menu_item = gtk_menu_item_new_with_label (menu_item_txt);
 
                     g_signal_connect_swapped (menu_item, "activate", G_CALLBACK (expand_or_collapse_selected_rows), 
